@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2001 Oliver Heidelbach
+@c Copyright (C) 1993/2002 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -34,7 +34,7 @@ Commodore 64 [computer] (Commodore)
 Cell Arrival (ATM)
 
 @item CA
-Certification Authority (cryptography)
+Certification Authority (cryptography, PKI)
 
 @item CA
 Computer Animation
@@ -229,7 +229,7 @@ Computer Aided Software Engineering
 Computer Aided Service Handling (Ashton-Tate), "C.A.S.H."
 
 @item CAST
-??? (cryptography)
+Carlisle Adams and Stafford Tavares (cryptography)
 
 @item CAST
 Computer Aided Software Testing
@@ -414,6 +414,9 @@ Cerberus Central Limited (manufacturer)
 @item CCM
 Change Configuration Management
 
+@item CCM
+CORBA Component Model (CORBA)
+
 @item CCNC
 Common Channel Network Controller
 
@@ -513,6 +516,9 @@ Communications Decency Act (Internet, USA)
 @item CDA
 Compound Document Architecture (DEC)
 
+@item CDATA
+Character DATA (XML, PCDATA)
+
 @item CDB
 Command Descriptor Block
 
@@ -552,6 +558,9 @@ Compact Disk - Erasable (CD), "CD-E"
 @item CDE
 Cooperative Development Environment (Oracle)
 
+@item CDEF
+Control DEfinition Functions (Apple, MDEF)
+
 @item CDF
 Channel Definition Format (MS, Internet, XML)
 
@@ -577,7 +586,7 @@ Control Development Toolkit (MS, VB)
 Compressed Data Mode
 
 @item CDMA
-Code Division Multiple Access (DFUe)
+Code Division Multiple Access (telecommunication, mobile-systems)
 
 @item CDMIDI
 Compact Disk + Musical Instruments Digital Interface (CD, MIDI), "CD+MIDI" 
@@ -594,6 +603,9 @@ Chinese DOMAIN Name Consortium (org., Internet, DOMAIN)
 @item CDO
 Collaboration Data Objects (WSH, MS)
 
+@item CDO
+Common Data Objects (MS, ASP)
+
 @item CDPC
 Cellular Digital Packet Data
 
@@ -681,6 +693,9 @@ CICS Enhanced Command Interpreter (IBM, CICS)
 @item CEECEB
 Central and Eastern European Countries EDIFACT Board (org., EDIFACT), "CEEC/EB"
 
+@item CEFACT
+CEntre for Facilitation of procedures and practices in Administration, Commerce and Transport
+
 @item CEG
 Continuous Edge Graphics (Grafik, IC)
 
@@ -744,6 +759,9 @@ Consumer Electronics Show (fair, USA)
 @item CESAR
 Central Employment Search And Retrieval (WWW)
 
+@item CESG
+Communications-Electronics Security Group (org., UK, GCHQ)
+
 @item CET
 Central European Time [+0100] (TZ, MET)
 
@@ -756,6 +774,9 @@ Carry Flag (assembler)
 @item CF
 Compact Flash [card]
 
+@item CF
+Compact Framework (MS, .NET)
+
 @item CFA
 Center for Architecture (org., JIEO, DISA)
 
@@ -780,6 +801,12 @@ Compact Font Format (Adobe)
 @item CFI
 CAD Framework Initiative (org., CAD)
 
+@item CFM
+Clock From Master (CTM, Rambus)
+
+@item CFM
+Code Fragment Manager (Apple)
+
 @item CFM
 ConFiguration Management (FDDI, SMT)
 
@@ -792,6 +819,9 @@ Cold Fusion Markup Language
 @item CFP
 Call For Papers
 
+@item CFP
+Contention Free Period (PCF, MAC)
+
 @item CFS
 Center for Standards (org., JIEO, DISA)
 
@@ -963,6 +993,9 @@ Computer-Investitions-Programm
 @item CIPA
 Children's Internet Protection Act (Internet, USA, COPA)
 
+@item CIQ
+Customer Information Quality (OASIS, TC)
+
 @item CIR
 Committed Information Rate (ATM)
 
@@ -1018,7 +1051,7 @@ Cyclone Integrated Video Interfaces Controller (Apple)
 Commercial Internet eXchange (ISP)
 
 @item CL
-Column Address Strobe Latency (CAS)
+Column Address Strobe Latency (CAS, IC)
 
 @item CL
 ConnectionLess (CO)
@@ -1026,6 +1059,9 @@ ConnectionLess (CO)
 @item CL
 Control Language (IBM, OS/400)
 
+@item CL
+Conversion Layer (HiperLAN/2, UMTS)
+
 @item CLASS
 Centralized Local Area Selective Signaling
 
@@ -1042,7 +1078,7 @@ Certified Lotus Engineer (Lotus)
 Competitive Local Exchange Carrier
 
 @item CLI
-Call Level Interface (SAQ, X/Open, Informix, ...)
+Call Level Interface (DB, SAG, X/Open, Oracle, Informix, MS, ...)
 
 @item CLI
 CLear Interrupt (assembler)
@@ -1051,7 +1087,7 @@ CLear Interrupt (assembler)
 Command Line Interpreter / Interface (OS)
 
 @item CLI
-Common Language Infrastructure (MS)
+Common Language Infrastructure (MS, .NET, ECMA)
 
 @item CLIC
 Chemnitzer LInux Cluster (Linux, Chemnitz), "CLiC"
@@ -1089,9 +1125,15 @@ Cell Loss Priority (UNI, ATM, CLR)
 @item CLR
 Cell Loss Ratio (UNI, ATM, QOS)
 
+@item CLR
+Common Language Runtime (MS, CLI, .NET)
+
 @item CLS
 Card Loading Signal
 
+@item CLS
+Common Language Specification (OOP, CLR, MS, .NET)
+
 @item CLSF
 ConnectionLess Service Function
 
@@ -1191,6 +1233,9 @@ Complementary-symmetry Metal-Oxide Semiconductor (IC)
 @item CMOT
 CMIP Over TCP (OSI, RFC 1189, CMIP, TCP)
 
+@item CMP
+Container-Managed Persistence [beans] (Java, EJB)
+
 @item CMP
 Cooperative Marketing Partner (DEC)
 
@@ -1443,6 +1488,12 @@ Character-Oriented Protocol
 @item COPA
 Child Online Protection Act (Internet, USA, CIPA)
 
+@item COPS
+Common Open Policy Service protocol (RFC 2748)
+
+@item COPSPR
+Common Open Policy Service for Policy Provisioning (COPS, RFC 3084), "COPS-PR"
+
 @item CORAN
 Communication ORiented Application aNalysis
 
@@ -1512,6 +1563,9 @@ Character Orientated Windows (MS, SAA, UI)
 @item CP
 Connection Processor
 
+@item CP
+Contention Period (DCF, MAC)
+
 @item CP
 Control Point (IBM, SNA)
 
@@ -1521,6 +1575,9 @@ Control Program (IBM, OS, VM/ESA, VM)
 @item CP
 Coordination Point (ISO 9646-3, TTCN)
 
+@item CPA
+Collaboration Protocol Agreements (ebXML)
+
 @item CPAN
 Comprehensive PERL Archive Network (PERL)
 
@@ -1605,6 +1662,9 @@ Control Program / ??? (CP/NET, CP/M, OS), "CP/NOS"
 @item CPODA
 Contention Priority Orientated Demand Assignment (MAC, PODA)
 
+@item CPP
+Collaboration Protocol Profiles (ebXML)
+
 @item CPPS
 Card / Paper tape Programming System (OS, IBM)
 
@@ -1695,6 +1755,9 @@ Carriage Return - Line Feed (ASCII, DOS)
 @item CRM
 Customer Relationship Management
 
+@item CRML
+Customer Relationships Markup Language (xCRL, predecessor)
+
 @item CRP
 Candidate Rendezvous Point (PIM, RP, Multicast), "C-RP"
 
@@ -1903,7 +1966,7 @@ Cell Switch Router (Toshiba)
 Clock Synchronous Random Access Memory (RAM, IC)
 
 @item CSS
-Cascading Style Sheets (HTML, WWW,  JavaScript)
+Cascading Style Sheets (HTML, XML, WWW,  JavaScript)
 
 @item CSS
 Computer Sub System
@@ -1986,6 +2049,9 @@ Command TERMinal (DEC)
 @item CTI
 Computer Telephony Integration
 
+@item CTM
+Clock To Master (CFM, Rambus)
+
 @item CTM
 Communication Trunk of Medium range Mil., Germany
 
@@ -2007,6 +2073,9 @@ Cipher Text Stealing [mode] (cryptography)
 @item CTS
 Clear To Send (MODEM, RS-232)
 
+@item CTS
+Common Type System (OOP, CLR, MS, .NET)
+
 @item CTS
 Conformance Testing Service (OSTC)
 
@@ -2038,7 +2107,7 @@ Console teleTYpe
 Call Up (Unix)
 
 @item CU
-[L]       [see you [Later]] (slang, Usenet, IRC)
+[L]       [see you [Later]] (telecommunication-slang, Usenet, IRC)
 
 @item CUA
 Common User Application
@@ -2052,6 +2121,9 @@ Character User Interface (UI)
 @item CUI
 Common User Interface (AMS, UI)
 
+@item CUP
+Competitive UPgrade (MS)
+
 @item CUSI
 Configurable Unified Search Interface (WWW)
 
@@ -2064,6 +2136,12 @@ Control Unit Terminal
 @item CUU
 ComputerUnterstuetzte Unterweisung
 
+@item CVD
+Chemical Vapor Deposition
+
+@item CVE
+Common Vulnerabilities and Exposures
+
 @item CVF
 Compressed Volume File (DOS)
 
@@ -2077,11 +2155,14 @@ Computer Vision Syndrome
 Concurrent Versions System (Unix)
 
 @item CVSD
-Continuous Variable Delta Modulation (DFUe)
+Continuous Variable Delta Modulation (telecommunication)
 
 @item CVSELP
 Codex Vector Sum Excited Linear Prediction [algorithm] (Motorola, VOFR)
 
+@item CVW
+MITRE Collaborative Virtual Workspace license
+
 @item CWI
 Centrum voor Wiskunde en Informatica (org., Netherlands)
 
@@ -2100,6 +2181,9 @@ Character Width Table
 @item CXI
 Common X-windows Interface (Unix)
 
+@item CXML
+Commerce eXtensible Markup Language (XML), "cXML"
+
 @item CYMK
 Cyan, Yellow, Magenta, blacK (color system)
 
