@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2001 Oliver Heidelbach
+@c Copyright (C) 1993/2002 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -49,7 +49,7 @@ File Access Data Unit (FTAM)
 Field Application Engineer
 
 @item FAG
-FernmeldeAnlagenGesetz DFUe, Germany
+FernmeldeAnlagenGesetz telecommunication, Germany
 
 @item FAIS
 Finnish Artificial Intelligence Society (org., Finland, AI)
@@ -73,7 +73,7 @@ Flow Attribute Notification Protocol (Toshiba, RFC 2129)
 Family Application Programmer Interface (DOS, VDM, API)
 
 @item FAQ
-Frequently Asked Questions (slang, Usenet)
+Frequently Asked Questions (telecommunication-slang, Usenet)
 
 @item FAR
 False Acception Rate
@@ -157,7 +157,7 @@ File Control BlockS (DOS)
 Federal Communications Commission (org., USA)
 
 @item FCC
-Forward Carbon Copy (DFUe)
+Forward Carbon Copy (telecommunication)
 
 @item FCCH
 Frequency Correction CHannel (GSM, mobile-systems)
@@ -171,6 +171,9 @@ Floating Car Data
 @item FCFS
 First Come, First Served
 
+@item FCH
+Frame Control Channel (HiperLAN/2)
+
 @item FCI
 Fibre Channel Interface
 
@@ -222,6 +225,9 @@ Fast Discrete Cosine Transformation (DCT)
 @item FDD
 Floppy Disk Drive
 
+@item FDD
+Frequency Division Duplex (mobile-systems)
+
 @item FDDI
 Fiber Distributed Data Interface (ANSI, ISO 8314)
 
@@ -255,6 +261,9 @@ Functional Device Object
 @item FDT
 Formal Description Technique
 
+@item FDTDMA
+Frequency Division/Time Division Multiple Access (mobile-systems, GSM), "FD/TDMA"
+
 @item FDX
 Full DupleX
 
@@ -297,6 +306,9 @@ Finite Elemente Methode
 @item FEN
 Free-net Erlangen/Nuernberg
 
+@item FEP
+Firewall Enhancement Protocol (RFC 3093)
+
 @item FEP
 Front End Processor
 
@@ -366,6 +378,9 @@ Frequency Hopping Spread Spectrum (WLAN)
 @item FIA
 Fiberoptic Industry Association (org.)
 
+@item FIB
+Forwarding Information Base (router, LAN, Internet)
+
 @item FIBU
 FInanzBUchhaltung
 
@@ -423,6 +438,9 @@ Foundation for Intelligent Physical Agents (org., Agents)
 @item FIPS
 Federal Information Processing Standard (NIST, USA)
 
+@item FIQ
+Fast Interrupt reQuest (ARM, RISC)
+
 @item FIR
 Fast IRDA (IRDA)
 
@@ -567,6 +585,9 @@ FTP Operation Over Big Address Records (RFC 1639, FTP)
 @item FOOT
 Forum for Object Oriented Technology (CERN, OOP)
 
+@item FOP
+Formatting Object Processor (Apache)
+
 @item FORMEX
 FORMalised EXchange of electronic publications (SGML, Europe)
 
@@ -636,6 +657,9 @@ Formal Public Identifier (DTD, SGML)
 @item FPI
 Functional Process Improvement
 
+@item FPK
+Fast Packet Keying (WLAN, WEP, RSA, cryptography)
+
 @item FPLA
 Field Programmable Logic Array
 
@@ -669,6 +693,9 @@ Floating Point Processor
 @item FPP
 FORTRAN Pre-Processor (FORTRAN)
 
+@item FPP
+Full Packaged Product (MS)
+
 @item FPR
 Fast Packet Relay (FPS, FPA)
 
@@ -757,7 +784,7 @@ File System Hierarchy (Linux, LSB)
 Full Scale InPut (FSOP)
 
 @item FSK
-Frequency Shift Keying (DFUe)
+Frequency Shift Keying (telecommunication)
 
 @item FSM
 Finite State Machine (TTCN, ...)
@@ -810,6 +837,9 @@ Floptical Technology Association (3M u.a.)
 @item FTAM
 File Transfer, Access  and Management (GOSIP, ISO 8571/8572)
 
+@item FTBFS
+Fails To Build From Source (Linux, Debian, slang)
+
 @item FTC
 Federal Trade Commission (org., USA)
 
@@ -868,7 +898,7 @@ Freie Universitaet Berlin (org.)
 Fouled / Fucked Up Beyond All Belief (slang, Usenet, IRC)
 
 @item FUBAR
-Fouled / Fucked Up Beyond All Recognition / Repair (slang, Usenet, IRC)
+Fouled / Fucked Up Beyond All Recognition / Repair (telecommunication-slang, Usenet, IRC)
 
 @item FUD
 Fear, Uncertainty, & Doubt (slang, IBM)
@@ -879,13 +909,14 @@ Flow Update Notification [message] (LFAP)
 @item FUNI
 Frame User Network Interface
 
-FUeV          Fernmeldeanlagen-UeberwachungsVerordnung
+@item FUEV
+Fernmeldeanlagen-UeberwachungsVerordnung
 
 @item FWH
 FirmWare Hub (BIOS, Intel)
 
 @item FWIW
-For What It's Worth (slang, Usenet, IRC)
+For What It's Worth (telecommunication-slang, Usenet, IRC)
 
 @item FWT
 Fast Wavelet Transformation
@@ -894,7 +925,7 @@ Fast Wavelet Transformation
 FiXed point Unit (POWER, CPU)
 
 @item FYI
-For Your Information (slang, Usenet, IRC)
+For Your Information (telecommunication-slang, Usenet, IRC)
 
 @item FZA
 ??? [compression]
