@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2001 Oliver Heidelbach
+@c Copyright (C) 1993/2002 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -13,7 +13,7 @@
 Mandatory Access Control (MLS)
 
 @item MAC
-Media Access Control (ISO, OSI)
+Media Access Control (ISO, OSI, LAN, , WLAN, ...)
 
 @item MAC
 Membership Advisory Committee (ICANN)
@@ -231,6 +231,9 @@ Microwave Communications Incorporated
 @item MCL
 Media Communication Lab (org., Uni Boston, USA)
 
+@item MCM
+Multi Carrier Modulation
+
 @item MCM
 MultiChip Module (CPU)
 
@@ -339,6 +342,9 @@ Mail Delivery Agent
 @item MDA
 Medicated Digest Authentication (HTTP)
 
+@item MDA
+Model Driven Architecture (CASE)
+
 @item MDA
 Monochrome Display Adapter (IBM, PC)
 
@@ -366,6 +372,9 @@ MultiDimensional DataBase (DB)
 @item MDE
 ??? DatenErfassung
 
+@item MDEF
+Menu DEfinintion Functions (Apple, CDEF)
+
 @item MDI
 Medium Dependent Interface (ethernet)
 
@@ -387,6 +396,12 @@ MODEM Developers Kit (MODEM, MS)
 @item MDL
 Microstation Development Language (CAD)
 
+@item MDM
+MicroDiskModule
+
+@item MDM
+Mobile Device Management (CA, Unicenter)
+
 @item MDRAM
 Multibank Dynamic Random Access Memory (RAM, DRAM, IC)
 
@@ -421,7 +436,7 @@ Mapping Entity
 Millennium Edition (MS, Windows)
 
 @item MEG
-Mega Evil Grin (slang, Usenet, IRC)
+Mega Evil Grin (telecommunication-slang, Usenet, IRC)
 
 @item MEGA
 MessdatenErfassung und Graphische Auswertung
@@ -430,7 +445,7 @@ MessdatenErfassung und Graphische Auswertung
 Matsushita Electronics Incorporated (manufacturer, Japan)
 
 @item MEL
-Maya Embedded Language
+Maya Embedded Language (Maya)
 
 @item MEMS
 Micro-ElectroMechanical System
@@ -595,7 +610,7 @@ MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RF
 Management Interface
 
 @item MIA
-Missing In Action (DFUe, Usenet, IRC)
+Missing In Action (telecommunication, Usenet, IRC)
 
 @item MIAW
 Movie In A Window
@@ -627,6 +642,9 @@ MICO Is CORBA (ORB, CORBA, Uni Frankfurt)
 @item MID
 Message IDentifier (ATM)
 
+@item MID
+Mobile Information Device
+
 @item MIDI
 Musical Instruments Digital Interface (MIDI)
 
@@ -892,7 +910,7 @@ Module Making System (VMS)
 Multilevel Mail Server
 
 @item MMS
-Multimedia Message Service
+Multimedia Messaging Service (mobile-systems)
 
 @item MMU
 Mass Memory Unit
@@ -1014,6 +1032,9 @@ Microsoft Online Services Partnership (MSN)
 @item MOSPF
 Multicast [extensions to ] Open Shortest Path First [routing] (IP, OSPF, RFC 1584)
 
+@item MOSRO
+MObiles-Sicherheits-ROboter-System
+
 @item MOST
 Media Orientated Systems Transport
 
@@ -1032,6 +1053,9 @@ More Of The Sameold Sameold (Usenet)
 @item MOU
 Memorandum Of Understanding (IPOC, TLD, Internet)
 
+@item MOUS
+Microsoft Office User Specialist (MS, Windows)
+
 @item MOVE
 Microsoft Overlay Virtual Environment (MS)
 
@@ -1135,7 +1159,7 @@ Microsoft Point-to-Point Compression (MS, RFC 2118)
 Multi Purpose Peripheral Device
 
 @item MPPE
-Microsoft Point to Point Encryption (MS, cryptography)
+Microsoft Point to Point Encryption (MS, cryptography, RFC 3078)
 
 @item MPPP
 Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend)
@@ -1278,6 +1302,9 @@ Most Recently Used
 @item MRX
 MagnetoResistive eXtended [technology] (HDD)
 
+@item MS
+Memory Stick
+
 @item MS
 Message Store
 
@@ -1368,6 +1395,9 @@ Micro-Star International (manufacturer, Taiwan)
 @item MSIE
 MicroSoft Internet Explorer (MS, WWW, MSIE)
 
+@item MSIL
+MicroSoft Intermediate Language (MS, .NET, CLI)
+
 @item MSISDN
 Mobile Station ISDN Number (PLMN, GSM, mobile-systems), "MS-ISDN"
 
@@ -1626,7 +1656,8 @@ Master Upper Tester (ISO 9646-3, TTCN)
 @item MUTOS
 MultiUser-/multitasking Operating System (GDR, OS)
 
-MUeW          eW MonopolUebertragungsWeg, "MueW"
+@item MUEW
+eW MonopolUebertragungsWeg, "MueW"
 
 @item MUX
 MUltipleXer
